@@ -918,7 +918,7 @@ pick_an_ai(SDL_Surface *screen, char *msg, AI_Players *AI)
     wrg = create_single_wrg( AI->n + 1 );
     for (i=0; i<AI->n ; i++) {
 	char buf[1024];
-	sprintf(buf,"\"%s\" : %s", AI->player[i].name, AI->player[i].msg);
+	SPRINTF(buf,"\"%s\" : %s", AI->player[i].name, AI->player[i].msg);
 	wrg->wr[0].label[i] = strdup(buf);
     }
 
