@@ -11,9 +11,9 @@
 #include <stdarg.h>
 #include <sys/stat.h>
 
-#include "SDL.h"
-#include "SDL_main.h"
-#include "SDL_ttf.h"
+#include "SDL/SDL.h"
+#include "SDL/SDL_main.h"
+#include "SDL/SDL_ttf.h"
 
 #if HAVE_SYS_SOCKET_H
 #	include <sys/socket.h>
@@ -149,11 +149,11 @@ load_options(char * filespec)
 {
     FILE *fin = fopen(filespec, "rt");
 
-    Options.full_screen = FALSE;
+    Options.full_screen = TRUE;
     Options.sound_wanted = TRUE;
     Options.flame_wanted = TRUE;
     Options.bpp_wanted = 0;
-    Options.key_repeat_delay = 16;
+    Options.key_repeat_delay = 8;
     Options.special_wanted = FALSE;
     Options.faster_levels = FALSE;
     Options.upward_rotation = TRUE;
@@ -612,7 +612,7 @@ play_NETWORK(color_styles cs, piece_styles ps, sound_styles ss,
     SEND(&cs.style[cs.choice]->num_color, sizeof(int));
     RECV(&their_data, sizeof(int));
     if (their_data != cs.style[cs.choice]->num_color) {
-	sprintf(message,"The # of colors in your styles are not equal. (%d/%d)",
+	SPRINTF(message,"The # of colors in your styles are not equal. (%d/%d)",
 		cs.style[cs.choice]->num_color, their_data);
 	goto known_error;
     }
@@ -620,7 +620,7 @@ play_NETWORK(color_styles cs, piece_styles ps, sound_styles ss,
     SEND(&ps.style[ps.choice]->num_piece, sizeof(int));
     RECV(&their_data, sizeof(int));
     if (their_data != ps.style[ps.choice]->num_piece) {
-	sprintf(message,"The # of shapes in your styles are not equal. (%d/%d)",
+	SPRINTF(message,"The # of shapes in your styles are not equal. (%d/%d)",
 		ps.style[ps.choice]->num_piece, their_data);
 	goto known_error;
     }
@@ -628,14 +628,14 @@ play_NETWORK(color_styles cs, piece_styles ps, sound_styles ss,
     SEND(&Options.special_wanted, sizeof(int));
     RECV(&their_data, sizeof(int));
     if (their_data != Options.special_wanted) {
-	sprintf(message,"You must both agree on whether to use Power Pieces");
+	SPRINTF(message,"You must both agree on whether to use Power Pieces");
 	goto known_error;
     }
 
     SEND(&Options.faster_levels, sizeof(int));
     RECV(&their_data, sizeof(int));
     if (their_data != Options.special_wanted) {
-	sprintf(message,"You must both agree on Double Difficulty");
+	SPRINTF(message,"You must both agree on Double Difficulty");
 	goto known_error;
     }
 
@@ -753,9 +753,9 @@ play_NETWORK(color_styles cs, piece_styles ps, sound_styles ss,
     /* error conditions! */
 error: 
     if (error_msg) 
-	sprintf(message,"Network Error: %s",error_msg);
+	SPRINTF(message,"Network Error: %s",error_msg);
     else 
-	sprintf(message,"Network Error: %s",strerror(errno));
+	SPRINTF(message,"Network Error: %s",strerror(errno));
 known_error: 
     clear_screen_to_flame();
     give_notice(message, 0);
@@ -821,7 +821,7 @@ play_MARATHON(color_styles cs, piece_styles ps, sound_styles ss,
 	}
 	my_adj[0] = -1;
 	level[0]++;
-	sprintf(message,"Up to Level %d!",level[0]);
+	SPRINTF(message,"Up to Level %d!",level[0]);
 	if (give_notice(message, 1)) {
 	    return level[0];
 	}
@@ -887,12 +887,12 @@ play_SINGLE(color_styles cs, piece_styles ps, sound_styles ss,
 		if (my_adj[0] == ADJUST_UP && my_adj[1] == ADJUST_UP &&
 			my_adj[2] == ADJUST_UP)  /* go up! */ {
 		    level[0]++;
-		    sprintf(message,"Up to level %d!",level[0]);
+		    SPRINTF(message,"Up to level %d!",level[0]);
 		}
 		else if (my_adj[0] == ADJUST_DOWN && my_adj[1] == ADJUST_DOWN &&
 			my_adj[2] == ADJUST_DOWN) { /* devolve! */
 		    level[0]--;
-		    sprintf(message,"Down to level %d!",level[0]);
+		    SPRINTF(message,"Down to level %d!",level[0]);
 		}
 	    }
 	    if (give_notice(message, 1) == 1) { /* explicit quit */
@@ -916,7 +916,7 @@ main(int argc, char *argv[])
     AI_Players *ai;
     Grid g[2];
     int renderstyle = TTF_STYLE_NORMAL;
-    int flags;
+    unsigned int flags;
     Uint32 time_now;
     SDL_Event event;
 
@@ -929,7 +929,7 @@ main(int argc, char *argv[])
 #else
     {
 	char filespec[2048];
-	sprintf(filespec,"%s/.atrisrc", getenv("HOME"));
+	SPRINTF(filespec,"%s/.atrisrc", getenv("HOME"));
 	load_options(filespec);
     }
 #endif
@@ -945,7 +945,12 @@ main(int argc, char *argv[])
     Debug("SDL initialized.\n");
 
     /* Initialize the display in a 640x480 native-depth mode */
-    flags = SDL_HWSURFACE | SDL_HWPALETTE | SDL_SRCCOLORKEY | SDL_ANYFORMAT; 
+    flags = // SDL_HWSURFACE |  
+            SDL_SWSURFACE | 
+	    SDL_FULLSCREEN | 
+            // SDL_SRCCOLORKEY | 
+            // SDL_ANYFORMAT |
+            0; 
     if (Options.full_screen) flags |= SDL_FULLSCREEN;
     screen = SDL_SetVideoMode(640, 480, Options.bpp_wanted, flags);
     if ( screen == NULL ) PANIC("Could not set 640x480 video mode");
@@ -1124,7 +1129,7 @@ main(int argc, char *argv[])
 #else
     {
 	char filespec[2048];
-	sprintf(filespec,"%s/.atrisrc", getenv("HOME"));
+	SPRINTF(filespec,"%s/.atrisrc", getenv("HOME"));
 	save_options(filespec);
     }
 #endif
