@@ -415,7 +415,7 @@ draw_background(SDL_Surface *screen, int blockWidth, Grid g[],
 	    char buf[1024];
 	    SDL_FillRect(widget_layer, &layout.name[i], int_black);
 	    SDL_FillRect(screen, &layout.name[i], int_black);
-	    sprintf(buf,"Demo (%s)",name[i]);
+	    SPRINTF(buf,"Demo (%s)",name[i]);
 	    draw_string(buf, color_blue, layout.grid_border[i].x +
 		    layout.grid_border[i].w/2, layout.grid_border[i].y +
 		    layout.grid_border[i].h, DRAW_CENTER | DRAW_CLEAR | DRAW_UPDATE);
@@ -433,7 +433,7 @@ draw_background(SDL_Surface *screen, int blockWidth, Grid g[],
 	SDL_FillRect(widget_layer, &layout.score[i], int_black);
 	SDL_FillRect(screen, &layout.score[i], int_black);
 
-	sprintf(buf,"Level %d, Score:",level[i]);
+	SPRINTF(buf,"Level %d, Score:",level[i]);
 	draw_string(buf, color_blue, layout.grid_border[i].x,
 		layout.grid_border[i].y, DRAW_ABOVE | DRAW_CLEAR);
 
@@ -488,11 +488,11 @@ draw_background(SDL_Surface *screen, int blockWidth, Grid g[],
 		    &layout.adjust[0].symbol[i]);
 
 	    /* draw the textual tallies */
-	    sprintf(buf,"%d",my_adj[i]);
+	    SPRINTF(buf,"%d",my_adj[i]);
 	    draw_string(buf, color_red,
 		    layout.adjust[0].symbol[i].x - 10, 
 		    layout.adjust[0].symbol[i].y, DRAW_LEFT | DRAW_CLEAR);
-	    sprintf(buf,"%d",their_adj[i]);
+	    SPRINTF(buf,"%d",their_adj[i]);
 	    draw_string(buf, color_red,
 		    layout.adjust[0].symbol[i].x + layout.adjust[0].symbol[i].w + 10, 
 		    layout.adjust[0].symbol[i].y, DRAW_CLEAR);
@@ -666,11 +666,11 @@ draw_clock(int seconds)
 	/* setup code */
 
 	for (i=0;i<10;i++) {
-	    sprintf(buf,"%d",i);
+	    SPRINTF(buf,"%d",i);
 	    digit[i] = TTF_RenderText_Blended(font,buf,color_blue);
 	}
-	sprintf(buf,":"); digit[10] = TTF_RenderText_Blended(font,buf,color_red);
-	sprintf(buf,"-"); digit[11] = TTF_RenderText_Blended(font,buf,color_red);
+	SPRINTF(buf,":"); digit[10] = TTF_RenderText_Blended(font,buf,color_red);
+	SPRINTF(buf,"-"); digit[11] = TTF_RenderText_Blended(font,buf,color_red);
 
 	for (i=0;i<12;i++) {
 	    Assert(digit[i]);
@@ -683,7 +683,7 @@ draw_clock(int seconds)
 
     old_seconds = seconds;
 
-    sprintf(buf,"%d:%02d",seconds / 60, seconds % 60);
+    SPRINTF(buf,"%d:%02d",seconds / 60, seconds % 60);
 
     c = layout.time.x;
     layout.time.w = w * 5;
@@ -692,7 +692,7 @@ draw_clock(int seconds)
     SDL_FillRect(widget_layer, &layout.time, int_solid_black); 
 
     if (strlen(buf) > 5)
-	sprintf(buf,"----");
+	SPRINTF(buf,"----");
 
     if (strlen(buf) < 5)
 	layout.time.x += ((5 - strlen(buf)) * w) / 2;
@@ -741,7 +741,7 @@ draw_score(SDL_Surface *screen, int i)
 {
     char buf[256];
 
-    sprintf(buf, "%d", Score[i]);
+    SPRINTF(buf, "%d", Score[i]);
     draw_string(buf, color_red, 
 	    layout.score[i].x, layout.score[i].y, DRAW_LEFT | DRAW_CLEAR |
 	    DRAW_ABOVE | DRAW_UPDATE);
