@@ -94,7 +94,7 @@ static void OptionsMenu_setup()
     else
 	wrg->wr[OptionsMenu].label[Opt_UpwardRotation] = "Upward Rotation: Off";
 
-    sprintf(key_repeat_label,"Key Repeat: %.2d", Options.key_repeat_delay);
+    SPRINTF(key_repeat_label,"Key Repeat: %.2d", Options.key_repeat_delay);
     wrg->wr[OptionsMenu].label[Opt_KeyRepeat] = key_repeat_label;
 }
 
