@@ -184,7 +184,7 @@ load_piece_styles(void)
 	    while (j<i) {
 		struct dirent *this_file = readdir(my_dir);
 		if (!piece_Select(this_file)) continue;
-		sprintf(filespec,"styles/%s",this_file->d_name);
+		SPRINTF(filespec,"styles/%s",this_file->d_name);
 		retval.style[j] = load_piece_style(filespec);
 		if (strstr(retval.style[j]->name,"Default"))
 		    retval.choice = j;
@@ -421,7 +421,7 @@ load_color_styles(SDL_Surface * screen)
 	    while (j<i) {
 		struct dirent *this_file = readdir(my_dir);
 		if (!color_Select(this_file)) continue;
-		sprintf(filespec,"styles/%s",this_file->d_name);
+		SPRINTF(filespec,"styles/%s",this_file->d_name);
 		retval.style[j] = load_color_style(screen, filespec);
 		if (strstr(retval.style[j]->name,"Default"))
 		    retval.choice = j;
